from .core import HelpStylesFormatter, StyledCommand, StyledGroup, StyledMultiCommand
from .decorators import version_option

__all__ = [
    "HelpStylesFormatter",
    "StyledGroup",
    "StyledCommand",
    "StyledMultiCommand",
    "version_option",
]

__version__ = "0.3.0"



from pathlib import Path
from typing import Dict, List, Optional, Tuple

import click
from rich.console import Console
from rich.panel import Panel
from rich.syntax import Syntax
from rich.theme import Theme

from click_rich_help import StyledCommand, StyledGroup

CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])


def get_command_line_no() -> Dict[Optional[str], Optional[Tuple[int, int]]]:
    """get line numbers of commands for use in 'src'"""
    command: Optional[str] = None
    start: Optional[int] = None
    end: Optional[int] = None
    blanks: List[int] = []
    cmd_lines: Dict[Optional[str], Optional[Tuple[int, int]]] = {}
    with Path(__file__).open("r") as f:
        for line_no, line in enumerate(f):
            if line == "\n":
                blanks.append(line_no)
            if not start:
                if line.startswith("@cli"):
                    start = line_no
            if start and not command:
                if line.startswith("def "):
                    command = line[4:].split("(", 1)[0]
            if start and command:
                if [line_no - 1, line_no] == blanks[-2:]:
                    end = line_no
            if start and end:
                cmd_lines[command] = (start, end)
                command, start, end = None, None, None

    cmd_lines["all"] = None

    return cmd_lines


console = Console()


def print_syntax(
    command: str,
    line_range: Tuple[int, int] = None,
    background_color: str = None,
    code_width: int = 90,
    expand: bool = False,
    theme: str = "monokai",
) -> None:
    console.print(
        Panel(
            Syntax.from_path(
                __file__,
                line_range=line_range,
                background_color=background_color,
                code_width=code_width,
                line_numbers=True,
                theme=theme,
            ),
            expand=False,
            title=f"Source code for {command}",
        )
    )


@click.group(
    cls=StyledGroup,
    headers_style="yellow bold",
    options_style="cyan italic",
    metavar_style="red bold",
    context_settings=CONTEXT_SETTINGS,
)
def cli() -> None:
    """[underline]Click-rich-help example[/]

    Welcome to [info]click-rich-help[/], where we can
    leverage the great python app rich
    so we can improve the readability
    and usability of click-powered CLI's.

    Why?
    So we can make text [red]red[/], [yellow]yellow[/], or [green]green[/].

    Or maybe we want to [b]bold[/],[i]italic[/],[underline]underline[/],
    or [strike]strikethrough[/] our text?

    Let's do all of the above!

    [b i underline strike green]ALL[/]

    Checkout more examples, start with
    [yellow]python -m click_rich_help.examples cmd1 -h[/].

    Then test it for yourself!
    """
    pass


@cli.command()
@click.option("--count", default=1, help="some number")
@click.option("--pretty", help="[red][underline]underlined[/] red text", is_flag=True)
def cmd1(count: int, pretty: bool) -> None:
    """[red bold]Command 1...try me[/]

    Look at that red text. CRAZY!
    Try [cyan]python -m click_rich_help.example cmd2[/cyan]!
    You won't believe what you see.
    """
    console.print("Try again with -h")


@cli.command(cls=StyledCommand, options_style="green")
@click.option("--name", help="some string")
@click.option("--choices", help="make a choice", type=click.Choice(["yay", "nay"]))
@click.option("--shout/--no-shout", help="shout or don't")
def cmd2(name: str, choices: str, shout: bool) -> None:
    """A command of the second variety

    You should never do this in a help message but you [b i cyan]could[/]
    get wild and include emoji :wink:.

    Did you notice these options are green!

    Next try [yellow]python -m click_rich_help.example test[/]!

    \f
    secret text click doesn't want you to see
    """
    console.print("Try again with -h")


@cli.command(
    cls=StyledCommand,
    headers_style="bold blue underline",
    styles={"options": "italic"},
    theme=Theme(
        {
            "headers": "yellow",
            "code": "cyan reverse",
            "info": "dim cyan",
            "warning": "magenta",
            "danger": "bold red",
        }
    ),
)
@click.option(
    "--option", help="[headers]header color[/],[code]code[/],[danger]DANGER[/]"
)
def theme(option: str) -> None:
    """Color commands and help strings with themes

    In addition to declaring args with your desired style
    you can also define your style using a
    [code]rich.theme.Theme[/code] or a simple dictionary.

    If you already make use of a [code]rich.theme.Theme[/code]
    then it's simple to include it.

    \b
    For instance:
    Theme({
        "headers": "yellow",
        "info": "dim cyan",
        "warning": "magenta",
        "danger": "bold red"
    })

    Can add styles for use in doc strings and help text.
    While also updating the styles used for headers, options, metavars, etc.

    [headers]Headers![/]
    [info]INFO[/]
    [warning]WARNGING[/]
    [danger]DANGER[/]

    Use [yellow]python -m click_rich_help.example src theme[/] to view
    the [code]Theme[/code] style applied to this command.

    """
    console.print("Try again with -h")


@cli.command(
    cls=StyledCommand,
    metavar_style="strike yellow",
    options_custom_styles={"--string": "bold red", "--style": "u green"},
)
@click.option("--string", help="markup string to test with rich (use quotes!)")
@click.option("--style", help="color/style to test")
def test(string: str, style: str) -> None:
    """Test a markup string or color/style

    Use [yellow]python -m rich.color [/]for full list of options

    Or [yellow]python -m rich[/] for an idea of what you can do.

    [i]Note[/]: that support is terminal dependent, so use complex styles sparingly

    I made those metavars with a strikethrough...don't do that please.

    Also those options have custom colors..cool!
    """
    console.print("[b blue]Testing...")
    if not string and not style:
        console.print(
            "I want to help you test it but you need to give me a string or style to try."
        )
        console.print("\ncheck the help for more info")

    if string:
        console.print("[u]string:[/]")
        console.print(f">>> {string}")
    if style:
        console.print("[u]style:")
        console.print(">>>", end="")
        console.print("This is a text string for the style:", style=style, end="")
        console.print(f' "{style}" ')


@cli.command(cls=StyledCommand, headers_style="green", doc_style="green")
@click.option("--name", help="some string")
def cmd3(name: str) -> None:
    """why is doc_style important?

    The main reason this parameter exists is to apply a default
    styling across both short and long form doc strings in your app.

    Imporantly one can still colorize the docstring by using the
    [bold italic red]markup style of rich[/].
    """

    console.print("Try again with -h")


@cli.command()
@click.argument("command")
@click.option(
    "--theme", help="pygments theme", default="monokai", metavar="<theme name>"
)
def src(command: str, theme: str) -> None:
    """View the source code for a given [yellow]COMMAND[/]

    [i]HINTS[/]:

    - view the entire src code with "all"

    - view the main entrypoint with "cli"

    see [link]https://pygments.org/docs/styles/#getting-a-list-of-available-styles[/]
    for available styles to provide [yellow]--theme[/].
    """

    if command:
        cmd_lines = get_command_line_no()
        print_syntax(command, cmd_lines[command], theme=theme)


if __name__ == "__main__":
    cli()



import re
from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union

import click
from click.formatting import wrap_text
from rich.console import Console
from rich.style import Style
from rich.theme import Theme

from .utils import _colorize


class HelpStylesFormatter(click.HelpFormatter):
    options_regex = re.compile(r"-{1,2}[\w\-]+")

    def __init__(
        self,
        headers_style: str = None,
        options_style: str = None,
        metavar_style: str = None,
        doc_style: str = None,
        options_custom_styles: Dict[str, str] = None,
        styles: Dict[str, Union[str, Style]] = None,
        theme: Theme = None,
        *args: Any,
        **kwargs: Any,
    ):
        self.headers_style = headers_style
        self.options_style = options_style
        self.metavar_style = metavar_style
        self.doc_style = doc_style
        self.options_custom_styles = options_custom_styles
        self.styles = self._get_styles(styles, theme)
        self.console = self._load_console()
        super(HelpStylesFormatter, self).__init__(*args, **kwargs)

    def _get_styles(
        self,
        user_styles: Optional[Dict[str, Union[str, Style]]],
        theme: Optional[Theme],
    ) -> Dict[str, Union[str, Style]]:

        styles: Dict[str, Union[str, Style]] = {
            k: "none" for k in ["headers", "options", "metavar", "doc_style"]
        }
        additions: Dict[str, Union[str, Style]] = {
            k: v
            for k, v in {
                **{
                    "headers": self.headers_style,
                    "options": self.options_style,
                    "metavar": self.metavar_style,
                    "doc_style": self.doc_style,
                },
            }.items()
            if v
        }
        if user_styles:
            if isinstance(user_styles, dict):
                additions.update(user_styles)
            else:
                raise ValueError(
                    (
                        f"Invalid styles: {user_styles}\n\n"
                        "Styles must be a dict containing valid names/styles. "
                        "See rich for more info"
                    )
                )
        if theme:
            additions.update(theme.styles)

        # validate style definition and update
        styles.update(
            {
                name: style if isinstance(style, Style) else Style.parse(style)
                for name, style in additions.items()
            }
        )

        return styles

    def _load_console(self) -> Console:
        return Console(
            theme=Theme(self.styles, inherit=False),
            highlight=False,
            force_terminal=True,
        )

    def _get_opt_names(self, option_name: str) -> List[str]:
        opts = self.options_regex.findall(option_name)
        if not opts:
            return [option_name]
        else:
            # Include this for backwards compatibility
            opts.append(option_name.split()[0])
            return opts

    def _pick_color(self, option_name: str) -> Union[str, Style]:
        opts = self._get_opt_names(option_name)
        for opt in opts:
            if self.options_custom_styles and (
                opt in self.options_custom_styles.keys()
            ):
                return self.options_custom_styles[opt]
        return self.styles["options"]

    def _extract_metavar_choices(self, option_name: str) -> str:
        metavar = self.options_regex.sub("", option_name).replace(",", "").strip()

        if metavar == "/":
            return option_name
        else:
            return metavar

    def _write_definition(self, option_name: str) -> str:
        metavar = self._extract_metavar_choices(option_name)

        color = (
            self.styles["metavar"]
            if self.styles["metavar"] != "none"
            else self.styles["options"]
        )

        if not metavar == option_name:
            if "[" in metavar and "]" in metavar:
                choices = metavar.split("[")[1].split("]")[0].split("|")
                colorized_metavar = "[{}]".format(
                    "|".join(
                        [_colorize(self.console, choice, color) for choice in choices]
                    )
                )
            else:
                colorized_metavar = _colorize(self.console, metavar, color)

            term = option_name.replace(metavar, "")
            return (
                _colorize(self.console, term, self._pick_color(term))
                + colorized_metavar
            )

        elif "/" in option_name:
            return " / ".join(
                [
                    _colorize(self.console, flag.strip(), self._pick_color(option_name))
                    for flag in option_name.split("/")
                ]
            )
        else:

            return _colorize(self.console, option_name, self._pick_color(option_name))

    def write_usage(self, prog: str, args: str = "", prefix: str = None) -> None:
        if not prefix:
            prefix = "Usage"
        colorized_prefix = _colorize(self.console, prefix, style="headers", suffix=": ")
        super(HelpStylesFormatter, self).write_usage(
            prog, args, prefix=colorized_prefix
        )

    def write_heading(self, heading: str) -> None:
        colorized_heading = _colorize(self.console, heading, style="headers")
        super(HelpStylesFormatter, self).write_heading(colorized_heading)

    def write_dl(
        self, rows: Sequence[Tuple[str, str]], col_max: int = 30, col_spacing: int = 2
    ) -> None:
        colorized_rows: Sequence[Tuple[str, str]] = [
            (
                self._write_definition(row[0]),
                _colorize(self.console, row[1], "doc_style"),
            )
            for row in rows
        ]
        super(HelpStylesFormatter, self).write_dl(colorized_rows, col_max, col_spacing)

    def write_text(self, text: str) -> None:

        indent = " " * self.current_indent
        self.write(
            _colorize(
                self.console,
                wrap_text(
                    text,
                    self.width,
                    initial_indent=indent,
                    subsequent_indent=indent,
                    preserve_paragraphs=True,
                ),
                style="doc_style",
            )
        )
        self.write("\n")


class StyledGroup(click.Group):
    def __init__(
        self,
        headers_style: str = None,
        options_style: str = None,
        metavar_style: str = None,
        doc_style: str = None,
        options_custom_styles: Dict[str, str] = None,
        styles: Dict[str, Union[str, Style]] = None,
        theme: Theme = None,
        *args: Any,
        **kwargs: Any,
    ):
        self.headers_style = headers_style
        self.options_style = options_style
        self.metavar_style = metavar_style
        self.doc_style = doc_style
        self.options_custom_styles = options_custom_styles
        self.styles = styles
        self.theme = theme
        super(StyledGroup, self).__init__(*args, **kwargs)

    @classmethod
    def from_group(cls, group: click.Group) -> "StyledGroup":
        styled_group = cls()

        for key, value in group.__dict__.items():
            styled_group.__dict__[key] = value
        return styled_group

    def get_help(self, ctx: click.Context) -> str:
        formatter = HelpStylesFormatter(
            width=ctx.terminal_width,
            max_width=ctx.max_content_width,
            headers_style=self.headers_style,
            options_style=self.options_style,
            metavar_style=self.metavar_style,
            doc_style=self.doc_style,
            options_custom_styles=self.options_custom_styles,
            styles=self.styles,
            theme=self.theme,
        )
        self.format_help(ctx, formatter)
        return formatter.getvalue().rstrip("\n")

    def command(
        self, *args: Any, **kwargs: Any
    ) -> Callable[[Callable[..., Any]], click.Command]:
        kwargs.setdefault("cls", StyledCommand)
        kwargs.setdefault("headers_style", self.headers_style)
        kwargs.setdefault("options_style", self.options_style)
        kwargs.setdefault("metavar_style", self.metavar_style)
        kwargs.setdefault("doc_style", self.doc_style)
        kwargs.setdefault("options_custom_styles", self.options_custom_styles)
        kwargs.setdefault("styles", self.styles)
        kwargs.setdefault("theme", self.theme)
        return super(StyledGroup, self).command(*args, **kwargs)

    def group(
        self, *args: Any, **kwargs: Any
    ) -> Callable[[Callable[..., Any]], click.Group]:
        kwargs.setdefault("cls", StyledGroup)
        kwargs.setdefault("headers_style", self.headers_style)
        kwargs.setdefault("options_style", self.options_style)
        kwargs.setdefault("metavar_style", self.metavar_style)
        kwargs.setdefault("doc_style", self.doc_style)
        kwargs.setdefault("options_custom_styles", self.options_custom_styles)
        kwargs.setdefault("styles", self.styles)
        kwargs.setdefault("theme", self.theme)
        return super(StyledGroup, self).group(*args, **kwargs)


class StyledCommand(click.Command):
    def __init__(
        self,
        headers_style: str = None,
        options_style: str = None,
        metavar_style: str = None,
        doc_style: str = None,
        options_custom_styles: Dict[str, str] = None,
        styles: Dict[str, Union[str, Style]] = None,
        theme: Theme = None,
        *args: Any,
        **kwargs: Any,
    ):
        self.headers_style = headers_style
        self.options_style = options_style
        self.metavar_style = metavar_style
        self.doc_style = doc_style
        self.options_custom_styles = options_custom_styles
        self.styles = styles
        self.theme = theme
        super(StyledCommand, self).__init__(*args, **kwargs)

    @classmethod
    def from_command(cls, command: click.Command) -> "StyledCommand":
        styled_command = cls()
        for key, value in command.__dict__.items():
            styled_command.__dict__[key] = value
        return styled_command

    def get_help(self, ctx: click.Context) -> str:
        formatter = HelpStylesFormatter(
            width=ctx.terminal_width,
            max_width=ctx.max_content_width,
            headers_style=self.headers_style,
            options_style=self.options_style,
            metavar_style=self.metavar_style,
            doc_style=self.doc_style,
            options_custom_styles=self.options_custom_styles,
            styles=self.styles,
            theme=self.theme,
        )
        self.format_help(ctx, formatter)
        return formatter.getvalue().rstrip("\n")


class StyledMultiCommand(click.MultiCommand):
    def __init__(
        self,
        headers_style: str = None,
        options_style: str = None,
        metavar_style: str = None,
        doc_style: str = None,
        options_custom_styles: Dict[str, str] = None,
        styles: Dict[str, Union[str, Style]] = None,
        theme: Theme = None,
        *args: Any,
        **kwargs: Any,
    ):
        self.headers_style = headers_style
        self.options_style = options_style
        self.metavar_style = metavar_style
        self.doc_style = doc_style
        self.options_custom_styles = options_custom_styles
        self.styles = styles
        self.theme = theme
        super(StyledMultiCommand, self).__init__(*args, **kwargs)

    def get_help(self, ctx: click.Context) -> str:
        formatter = HelpStylesFormatter(
            width=ctx.terminal_width,
            max_width=ctx.max_content_width,
            headers_style=self.headers_style,
            options_style=self.options_style,
            metavar_style=self.metavar_style,
            doc_style=self.doc_style,
            options_custom_styles=self.options_custom_styles,
            styles=self.styles,
            theme=self.theme,
        )
        self.format_help(ctx, formatter)
        return formatter.getvalue().rstrip("\n")

    def resolve_command(
        self, ctx: click.Context, args: List[str]
    ) -> Tuple[Optional[str], Optional[click.Command], List[str]]:

        cmd_name, cmd, args[1:] = super(StyledMultiCommand, self).resolve_command(
            ctx, args
        )

        if isinstance(cmd, click.Group):
            cmd = StyledGroup.from_group(cmd)
        elif isinstance(cmd, click.Command):
            cmd = StyledCommand.from_command(cmd)

        if cmd:
            if not getattr(cmd, "headers_style", None):
                cmd.headers_style = self.headers_style
            if not getattr(cmd, "options_style", None):
                cmd.options_style = self.options_style
            if not getattr(cmd, "metavar_style", None):
                cmd.metavar_style = self.metavar_style
            if not getattr(cmd, "doc_style", None):
                cmd.doc_style = self.doc_style
            if not getattr(cmd, "options_custom_styles", None):
                cmd.options_custom_styles = self.options_custom_styles
            if not getattr(cmd, "styles", None):
                cmd.styles = self.styles
            if not getattr(cmd, "theme", None):
                cmd.theme = self.theme

        return cmd_name, cmd, args[1:]



import re
from typing import Callable

from click import version_option as click_version_option
from click.decorators import FC
from rich.console import Console

from .utils import _colorize


def version_option(
    version: str = None,
    prog_name: str = None,
    message: str = "%(prog)s, version %(version)s",
    message_style: str = None,
    prog_name_style: str = None,
    version_style: str = None,
    **kwargs: str,
) -> Callable[[FC], FC]:
    """
    :param prog_name_style: style of the prog_name.
    :param version_style: style of the version.
    :param message_style: default style of the message.

    for other params see Click's version_option decorator:
    https://click.palletsprojects.com/en/8.0.x/api/#click.version_option
    """
    console = Console(highlight=False)
    msg_parts = []
    for s in re.split(r"(%\(version\)s|%\(prog\)s)", message):
        if s == "%(prog)s":
            msg_parts.append(
                _colorize(console, prog_name, prog_name_style or message_style)
            )
        elif s == "%(version)s":
            msg_parts.append(
                _colorize(console, version, version_style or message_style)
            )
        else:
            msg_parts.append(_colorize(console, s, message_style))

    message = "".join(msg_parts)

    return click_version_option(
        version=version, prog_name=prog_name, message=message, **kwargs
    )



import os
from typing import Union

from rich.console import CaptureError, Console
from rich.style import Style


def _get_rich_output(
    console: Console, text: str = None, style: Union[str, Style] = None
) -> str:
    try:
        with console.capture() as capture:
            console.print(text, style=style, end="")
        return capture.get()
    except CaptureError:
        raise ValueError(f"Error capturing output for text: {text} and style: {style}")


def _colorize(
    console: Console,
    text: str = None,
    style: Union[str, Style] = None,
    suffix: str = None,
) -> str:
    if not style or "NO_COLOR" in os.environ:
        return (text or "") + (suffix or "")
    else:
        return _get_rich_output(console, text, style) + (suffix or "")



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['click_rich_help']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.0,<9.0', 'rich>=10.0']

setup_kwargs = {
    'name': 'click-rich-help',
    'version': '0.3.0',
    'description': 'make a beautiful click app with rich',
    'long_description': '<div id="top"></div>\n\n<!-- PROJECT SHIELDS -->\n[![Forks][forks-shield]][forks-url]\n[![Stargazers][stars-shield]][stars-url]\n[![Issues][issues-shield]][issues-url]\n[![MIT License][license-shield]][license-url]\n[![CircleCI][circleci-shield]][circleci-url]\n\n<!-- TODO: update asciicinema -->\n\n<!-- PROJECT LOGO -->\n<br />\n<div align="center">\n  <a href="https://github.com/daylinmorgan/click-rich-help">\n    <img src="https://raw.githubusercontent.com/daylinmorgan/click-rich-help/main/assets/logo.png" alt="Logo" width=400 >\n  </a>\n\n<h2 align="center">click-rich-help</h2>\n\n  <p align="center">\n    make a beautiful click app with rich\n  </p>\n</div>\n\n\n<!-- TABLE OF CONTENTS -->\n<details>\n  <summary>Table of Contents</summary>\n  <ol>\n    <li>\n      <a href="#about-the-project">About The Project</a>\n      <ul>\n        <li><a href="#built-with">Built With</a></li>\n      </ul>\n    </li>\n    <li>\n      <a href="#getting-started">Getting Started</a>\n      <ul>\n        <li><a href="#installation">Installation</a></li>\n      </ul>\n    </li>\n    <li><a href="#usage">Usage</a></li>\n    <li><a href="#contributing">Contributing</a></li>\n    <li><a href="#acknowledgments">Acknowledgments</a></li>\n  </ol>\n</details>\n\n\n\n## About The Project\n\n\nI wanted a simple python package to make my click app\'s help more readable.\n\nClick the on the cast below to see it in action!\n\n<a href="https://asciinema.org/a/iYiq7Xv2e8AgaSAMD1kEJHTkh"> <img src="https://asciinema.org/a/iYiq7Xv2e8AgaSAMD1kEJHTkh.svg" width=500> </a>\n\n\nSince writing this package the more opinionated [rich-click](https://github.com/ewels/rich-click) has been written.\nIf that output is more your speed, go check it out!\n\n## Getting Started\n\n### Installation\n\nwith pip:\n``` bash\npip install click-rich-help\n```\nwith conda/mamba:\n```bash\nconda install -c conda-forge click-rich-help\n```\n\n<p align="right">(<a href="#top">back to top</a>)</p>\n\n## Usage\n\nThere are currently (as of `v0.3.0`) several ways you can apply styles to your click app.\n\nYou apply the class to `click` groups or commands like so:\n\n```python\n@click.group(\n    cls=StyledGroup,\n)\ndef cli():\n    pass\n```\n\nNext you have several options for defining styles.\n\nPass named args to `click.group` or `click.command`.\n\n```python\n@click.group(\n    cls=StyledGroup,\n    headers_style="green",\n    options_style="yellow",\n    metavar_style="red",\n)\ndef cli():\n    pass\n```\n\nPass a dictionary containing the values with keys for each style:\n\n```python\n@click.group(\n    cls=StyledGroup,\n    styles = {\n      "headers":"green",\n      "options":"yellow",\n      "metavar":"red",\n    }\n)\ndef cli():\n    pass\n```\n\nYou can also provide a `rich.theme.Theme` and define the style itself in a separate file:\n\n`default.ini`:\n````ini\n[styles]\nheaders="green"\noptions="yellow"\nmetavar="red"\n````\n\n```python\n@click.group(\n    cls=StyledGroup,\n    theme=Theme.read("default.ini")\n)\ndef cli():\n    pass\n```\n\nThese options will be parsed in the order they are shown here. Meaning the precedence of styles is theme, styles, args.\n\nFor example the below command would have red headers.\n\n```python\n@click.group(\n    cls=StyledGroup,\n    headers_style="green",\n    styles={"headers":"yellow"}\n    theme=Theme({"headers":"red"})\n)\ndef cli():\n    pass\n```\n\nIn addition any string that would usually be passed to click will be\nparsed by `rich` to apply the needed colors and styles including any user defined styles.\n\nThis means you can use rich syntax in `click.option()` decorators as well as in docstrings of commands. For instance, you can have something like below.\n\n```python\n@click.command(\n    cls=StyledCommand,\n    options_style="italic cyan",\n    headers_style="bold yellow"\n)\n@click.option(\'--count\', default=1, help=\'[red]Number[/red] of greetings.\')\n@click.option(\'--name\', prompt=\'Your name\',\n              help=\'The person to greet.\')\ndef hello(count, name):\n    """Simple program that greets [options]NAME[/] for a total of [options]COUNT[/] times."""\n    for x in range(count):\n        click.echo(f"Hello {name}!")\n\nif __name__ == \'__main__\':\n    hello()\n```\n\nLastly, there is also support for styling all doc/help strings with the `doc_style` attribute.\n\nTo preview the included example module in your own terminal you can use two methods:\n\nW/o `click-rich-help` and w/ `asciinema`\n\n```bash\nasciinema play https://asciinema.org/a/iYiq7Xv2e8AgaSAMD1kEJHTkh\n```\n\nW/ `click-rich-help`  and `curl`\n\n```bash\ncurl -s https://raw.githubusercontent.com/daylinmorgan/click-rich-help/main/scripts/example.sh | bash\n```\n\nYou can also run it yourself if you have installed `click-rich-help`. Which you should!\n\n```bash\npython -m click_rich_help.example -h\n```\n\n<p align="right">(<a href="#top">back to top</a>)</p>\n\n\n## Contributing\nTo contribute please utilize `poetry` and `pre-commit`.\n\noptionally manage python installation with `conda`:\n\n```bash\nconda create -p ./env python poetry\n```\n\nThen follow the below steps\n1. Fork the Project\n2. Install the package and dev dependencies w/poetry(`cd click-rich-help; poetry install`)\n2. Create your Feature Branch (`git checkout -b feat/AmazingFeature`)\n3. Commit your Changes (`git commit -m \'Add some AmazingFeature\'`)\n4. Run the tests (`mypy click_rich_help; py.test tests`)\n5. Push to the Branch (`git push origin feat/AmazingFeature`)\n6. Open a Pull Request\n\n\n<p align="right">(<a href="#top">back to top</a>)</p>\n\n## Acknowledgments\n\n* [click](https://github.com/pallets/click)\n* [rich](https://github.com/willmcgugan/rich)\n* [click-help-colors](https://github.com/click-contrib/click-help-colors)\n\n<p align="right">(<a href="#top">back to top</a>)</p>\n\n\n\n<!-- MARKDOWN LINKS & IMAGES -->\n<!-- https://www.markdownguide.org/basic-syntax/#reference-style-links -->\n[contributors-shield]: https://img.shields.io/github/contributors/daylinmorgan/click-rich-help.svg?style=flat\n[contributors-url]: https://github.com/daylinmorgan/click-rich-help/graphs/contributors\n[forks-shield]: https://img.shields.io/github/forks/daylinmorgan/click-rich-help.svg?style=flat\n[forks-url]: https://github.com/daylinmorgan/click-rich-help/network/members\n[stars-shield]: https://img.shields.io/github/stars/daylinmorgan/click-rich-help.svg?style=flat\n[stars-url]: https://github.com/daylinmorgan/click-rich-help/stargazers\n[issues-shield]: https://img.shields.io/github/issues/daylinmorgan/click-rich-help.svg?style=flat\n[issues-url]: https://github.com/daylinmorgan/click-rich-help/issues\n[license-shield]: https://img.shields.io/github/license/daylinmorgan/click-rich-help.svg?style=flat\n[license-url]: https://github.com/daylinmorgan/click-rich-help/blob/main/LICENSE.txt\n[circleci-shield]: https://img.shields.io/circleci/build/gh/daylinmorgan/click-rich-help?style=flat\n[circleci-url]: https://img.shields.io/circleci/build/gh/daylinmorgan/click-rich-help\n',
    'author': 'Daylin Morgan',
    'author_email': 'daylinmorgan@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/daylinmorgan/click-rich-help',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
